<?php
// Implement a custom header for Corgi Love
// Set up the WordPress core custom header arguments and settings.
function corgi_love_custom_header_setup() {
	$args = array(
		// Text color and image (empty to use none).
		'default-text-color'     => '6f4008',
		'default-image'          => '%s/images/corgi-love-banner.jpg',

		// Set height and width, with a maximum value for the width.
		'height'                 => 300,
		'width'                  => 1024,

		// Callbacks for styling the header and the admin preview.
		'wp-head-callback'       => 'corgi_love_header_style',
		'admin-head-callback'    => 'corgi_love_admin_header_style',
		'admin-preview-callback' => 'corgi_love_admin_header_image',
	);

	add_theme_support( 'custom-header', $args );

	// Default custom headers packaged with the theme.
	// %s is a placeholder for the theme template directory URI.
	register_default_headers( array(
		'primary' => array(
			'url'           => '%s/images/corgi-love-banner.jpg',
			'thumbnail_url' => '%s/images/corgi-love-banner-thumbnail.jpg',
			'description'   => _x( 'Primary', 'header image description', 'corgi-love' )
		),
		'alternate' => array(
			'url'           => '%s/images/alt-corgi-love-banner.jpg',
			'thumbnail_url' => '%s/images/alt-corgi-love-banner-thumbnail.jpg',
			'description'   => _x( 'Alternate', 'header image description', 'corgi-love' )
		),
	) );
}
add_action( 'after_setup_theme', 'corgi_love_custom_header_setup', 11 );

// Style the header text displayed on the blog.
// get_header_textcolor() options: Hide text (returns 'blank'), or any hex value.
function corgi_love_header_style() {
	$header_image = get_header_image();
	$text_color   = get_header_textcolor();

	// If no custom options for text are set, let's bail.
	if ( empty( $header_image ) && $text_color == get_theme_support( 'custom-header', 'default-text-color' ) )
		return;

	// If we get this far, we have custom styles.
	?>
	<style type="text/css" id="corgi-love-header-css">
	<?php
		if ( ! empty( $header_image ) ) :
	?>
		.site-header {
			background: url(<?php header_image(); ?>) no-repeat scroll top;
			background-size: 1024px auto;
		}
	<?php
		endif;

		// Has the text been hidden?
		if ( ! display_header_text() ) :
	?>
		.site-title a,
		.site-description {
			position: absolute;
			clip: rect(1px 1px 1px 1px); /* IE7 */
			clip: rect(1px, 1px, 1px, 1px);
		}
	<?php
			if ( empty( $header_image ) ) :
	?>
		.site-header .home-link {
			min-height: 0;
		}
	<?php
			endif;

		// If the user has set a custom color for the text, use that.
		elseif ( $text_color != get_theme_support( 'custom-header', 'default-text-color' ) ) :
	?>
		.site-title a,
		.site-description {
			color: #<?php echo esc_attr( $text_color ); ?>;
		}
	<?php endif; ?>
	</style>
	<?php
}

// Style the header image displayed on the Appearance > Header admin panel.
function corgi_love_admin_header_style() {
	$header_image = get_header_image();
?>
	<style type="text/css" id="corgi-love-admin-header-css">
	.appearance_page_custom-header #heading {
		border: none;
		-webkit-box-sizing: border-box;
		-moz-box-sizing:    border-box;
		box-sizing:         border-box;
		<?php
		if ( ! empty( $header_image ) ) {
			echo 'background: url(' . esc_url( $header_image ) . ') no-repeat scroll top; background-size: 1600px auto;';
		} ?>
		padding: 0 20px;
	}
	#heading .home-link {
		-webkit-box-sizing: border-box;
		-moz-box-sizing:    border-box;
		box-sizing:         border-box;
		margin: 0 auto;
		max-width: 1024px;
		<?php
		if ( ! empty( $header_image ) || display_header_text() ) {
			echo 'min-height: 230px;';
		} ?>
		width: 100%;
	}
	<?php if ( ! display_header_text() ) : ?>
	#heading h1,
	#heading h2 {
		position: absolute !important;
		clip: rect(1px 1px 1px 1px); /* IE7 */
		clip: rect(1px, 1px, 1px, 1px);
	}
	<?php endif; ?>
	#heading h1 {
		margin: 0;
		padding: 58px 0 10px;
	}
	#heading h1 a {
		text-decoration: none;
	}
	#heading h1 a:hover {
		text-decoration: underline;
	}
	#heading h2 {
		margin: 0;
		text-shadow: none;
	}
	.default-header img {
		max-width: 230px;
		width: auto;
	}
	</style>
<?php
}

// Output markup to be displayed on the Appearance > Header admin panel.
// This callback overrides the default markup displayed there.
function corgi_love_admin_header_image() {
	?>
	<div id="heading" style="background: url(<?php header_image(); ?>) no-repeat scroll top; background-size: 1600px auto;">
		<?php $style = ' style="color:#' . get_header_textcolor() . ';"'; ?>
		<div class="home-link">
			<h1 class="displaying-header-text"><a id="name"<?php echo $style; ?> onclick="return false;" href="#"><?php bloginfo( 'name' ); ?></a></h1>
			<h2 id="desc" class="displaying-header-text"<?php echo $style; ?>><?php bloginfo( 'description' ); ?></h2>
		</div>
	</div>
<?php }
